@@ -576,6 +576,7 @@ gchar *
 application_get_command (const GnomeVFSMimeApplication *app)
 {
 	char *command;
+	const char *bad_chars = "$\'`\"\\!?*()[]&|@#:;"; /* similar to shell_escape but without ' ' */
 	
 	if (app->requires_terminal) {
 		char *terminal;
@@ -585,7 +586,7 @@ application_get_command (const GnomeVFSMimeApplication *app)
 		if (terminal == NULL)
 			return NULL;
 
-		command_to_exec = shell_escape (app->command);
+		command_to_exec = escape_str (app->command, bad_chars);
 		command = g_strconcat (terminal,
 				       " ",
 				       command_to_exec,
@@ -593,7 +594,7 @@ application_get_command (const GnomeVFSMimeApplication *app)
 		g_free (terminal);
 		g_free (command_to_exec);
 	} else
-		command = shell_escape (app->command);
+		command = escape_str (app->command, bad_chars);
 
 	return command;
 }
@@ -958,6 +959,15 @@ get_last_field (const char *line,
 }
 
 
+char *
+get_temp_work_dir (void)
+{
+	char temp_dir_template[] = "/tmp/fr-XXXXXX";
+	g_assert (mkdtemp (temp_dir_template) != NULL);
+	return g_strdup (temp_dir_template);
+}
+
+
 #define MAX_TRIES 50
 
 
